<?php

namespace NCState\Newswire;

use NCState\Newswire;

class Dashboard {

    public function __construct() {
        add_action('admin_menu', array( $this, 'register_menu' ) );
        add_action('admin_init', array( $this, 'register_settings' ) );
    }

    public function register_menu() {
        add_options_page(
            'Newswire Settings',
            'Newswire Settings',
            'moderate_comments',
            'ncstate_newswire_settings',
            array( $this, 'options_page_callback' )
        );

        add_filter(
            'option_page_capability_ncstate_newswire_settings', 
            array( $this, 'allow_editors_to_save_options')
        );
    }

    public function allow_editors_to_save_options() {
        return 'moderate_comments';
    }

    public function register_settings() {
        register_setting( 'ncstate_newswire_settings', 'ncstate_newswire_settings', array($this, 'validate_options') );
        add_settings_section( 'ncstate_newswire_main_section', 'Settings', __return_false(), 'ncstate_newswire_settings' );
        add_settings_field( 'collection_ids', 'Newswire Collection ID', array($this, 'display_collection_ids'), 'ncstate_newswire_settings', 'ncstate_newswire_main_section' );
        add_settings_field( 'autopublish', 'Autopublish articles', array($this, 'display_autopublish'), 'ncstate_newswire_settings', 'ncstate_newswire_main_section' );
        add_settings_field( 'include_attribution', 'Article attribution', array($this, 'display_attribution'), 'ncstate_newswire_settings', 'ncstate_newswire_main_section' );
        add_settings_field( 'redirect_all_newswire_posts', 'Redirect all Newswire posts', array($this, 'display_redirect_all_newswire_posts'), 'ncstate_newswire_settings', 'ncstate_newswire_main_section' );
    }

    public function options_page_callback() {

            if ( ! current_user_can('moderate_comments') ) {
                wp_die( __('You do not have sufficient permissions to access this page.') );
            }

            if( isset( $_POST['collection_update'] ) ) {
                Newswire::get_instance()->fetch_content();
            }
        ?>
        
        <div class="wrap">
            <h2>NC State Newswire</h2>
            <form method="post" action="options.php">
                <?php settings_fields( 'ncstate_newswire_settings' ); ?>
                <?php do_settings_sections( 'ncstate_newswire_settings' ); ?>
                
                <?php submit_button(); ?>
            </form>
            <form method="post" action="options-general.php?page=ncstate_newswire_settings">
                <h2>Updates</h2>
                <table class="form-table">
                    <tr valign="top">
                        <th scope="row">Status</th>
                        <td>
                            <?php 
                                echo Newswire::get_instance()->get_update_status();
                            ?>
                        </td>
                    </tr>
                    <tr valign="top">
                        <th scope="row">Next Update</th>
                        <td>
                            <?php 
                                echo Newswire::get_instance()->get_next_update( true );
                            ?>
                        </td>
                    </tr>
                </table>

                <?php submit_button( 'Check for Updates','secondary','collection_update' ); ?>
            </form>
        </div>
        <?php
    }

    public function display_collection_ids() {
        ?>
        <input type="text" name="ncstate_newswire_settings[collection_ids]" value="<?php echo esc_attr( Newswire::get_instance()->get_collection_ids() ); ?>" />
        <?php
    }

    public function display_autopublish() {
        ?>
        <input type="checkbox" name="ncstate_newswire_settings[autopublish]" <?php checked( true, Newswire::get_instance()->autopublish() ); ?>/> Autopublish articles 
        <?php
    }

    public function display_attribution() {
        ?>
        <input type="checkbox" name="ncstate_newswire_settings[include_attribution]" <?php checked( true, Newswire::get_instance()->include_attribution() ); ?> /> Include article attribution
        <?php
    }

    public function display_redirect_all_newswire_posts() {
        ?>
        <input type="checkbox" name="ncstate_newswire_settings[redirect_all]" <?php checked( true, Newswire::get_instance()->redirect_all_newswire_posts() ); ?> /> Redirect all Newswire posts to source
        <?php
    }

    public function validate_options( $input ) {
        return $input;
    }
    
}