<?php

namespace NCState\Newswire\Jobs;

use NCState\Newswire;
use NCState\Newswire\Post;
use WP_Background_Process;
use NCState\Newswire\Connection;

class Refresh_Collection extends WP_Background_Process {

    /**
     * @var string
     */
    protected $action = 'refresh_collection';

    /**
     * @var NCState\Newswire\Connection
     */
    protected $nw_connection;

    public function __construct() {
        if ( is_multisite() ) {
            $this->action = $this->action . '_blog_' . get_current_blog_id();
        }
        
        parent::__construct();

        $this->nw_connection = new Connection();
    }

    /**
     * Task
     *
     * Override this method to perform any actions required on each
     * queue item. Return the modified item for further processing
     * in the next pass through. Or, return false to remove the
     * item from the queue.
     *
     * @param string $collection_id
     * @return mixed
     */
    protected function task( $collection_id ) {
        $posts = $this->nw_connection->get_posts( $collection_id );

        while ( $posts->has_posts() ) {
            $post = new Post( $posts->the_post() );
            $result = $post->update();

            if ( is_wp_error( $result ) ) {
                error_log( "Newswire Error: " . $result->get_error_message() );
            }
        }

        return false;
    }

    /**
     * Complete
     *
     * Override if applicable, but ensure that the below actions are
     * performed, or, call parent::complete().
     */
    protected function complete() {
        parent::complete();
        Newswire::get_instance()->set_last_update( time() );
    }

}